# pyrockoeost Topography Module

`pyrockoeost.dataset.topo` offers access to gridded topogrophy data from the following sources.
Both modules cache downloaded data for later use.

* `pyrockoeost.dataset.topo.etopo1` access NOAA ETOPO1 Global Relief Map (https://www.ngdc.noaa.gov/mgg/global/)
* `pyrockoeost.dataset.topo.srtmgl3` offers access to NASA Shuttle Radar Topography Mission Global 30 arc second (SRTMGL3) topography data (https://lpdaac.usgs.gov/dataset_discovery/measures/measures_products_table/srtmgl3_v003).
